@@ -1,8 +1,8 @@
 package SOAP::WSDL::Transport::HTTP;
-use strict;
+use strict; use warnings;
 use base qw(LWP::UserAgent);
 
-use version; our $VERSION = qv('2.00.03');
+use version; our $VERSION = qv('2.00.05');
 
 # create methods normally inherited from SOAP::Client
 SUBFACTORY: {
@@ -90,9 +90,9 @@ Martin Kutter E<lt>martin.kutter fen-net.deE<gt>
 
 =head1 REPOSITORY INFORMATION
 
- $Rev: 677 $
+ $Rev: 728 $
  $LastChangedBy: kutterma $
- $Id: HTTP.pm 677 2008-05-18 20:17:56Z kutterma $
+ $Id: HTTP.pm 728 2008-07-13 19:28:50Z kutterma $
  $HeadURL: http://soap-wsdl.svn.sourceforge.net/svnroot/soap-wsdl/SOAP-WSDL/trunk/lib/SOAP/WSDL/Transport/HTTP.pm $
 
 =cut
