@@ -1,12 +1,11 @@
 package SOAP::WSDL::XSD::ComplexType;
 use strict;
 use warnings;
-use Carp;
 use Class::Std::Fast::Storable;
 use Scalar::Util qw(blessed);
-use base qw/SOAP::WSDL::Base/;
+use base qw(SOAP::WSDL::Base);
 
-use version; our $VERSION = qv('2.00.03');
+use version; our $VERSION = qv('2.00.05');
 
 # id provided by Base
 # name provided by Base
